build_snapshot_from_planned

Function build_snapshot_from_planned 

pub(crate) fn build_snapshot_from_planned(
    planned_project: &Project,
) -> Result<DeploymentSnapshot, DeploymentSnapshotError>
Build a deployment snapshot from a project graph by hashing all compiled objects.

This iterates through all objects in the project and computes their content hashes based on the normalized compiled representation.